@@ -6,19 +6,21 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.07 22:00:00                  #
+# Updated Date: 2025.08.31 23:00:00                  #
 # ================================================== #
 
 import os
 from typing import Optional
 
-from qasync import QApplication
+from PySide6.QtWidgets import QApplication
 
 from pygpt_net.core.tabs.tab import Tab
 from pygpt_net.core.events import Event, BaseEvent
 from pygpt_net.item.ctx import CtxItem
 from pygpt_net.utils import trans
 
+from .ui import UI
+
 
 class Audio:
     def __init__(self, window=None):
@@ -28,6 +30,7 @@ class Audio:
         :param window: Window instance
         """
         self.window = window
+        self.ui = UI(window)
         self.input_allowed_tabs = [
             Tab.TAB_NOTEPAD,
             Tab.TAB_CHAT,
@@ -37,9 +40,46 @@ class Audio:
     def setup(self):
         """Setup controller"""
         self.update()
+
+        # continuous input (notepad)
         if self.window.core.config.get("audio.input.continuous", False):
             self.window.ui.plugin_addon['audio.input.btn'].continuous.setChecked(True)
 
+        # auto turn (VAD)
+        if self.window.core.config.get("audio.input.auto_turn", False):
+            self.window.ui.nodes['audio.auto_turn'].box.setChecked(True)
+
+        # loop recording
+        if self.window.core.config.get("audio.input.loop", False):
+            self.window.ui.nodes['audio.loop'].box.setChecked(True)
+
+    def execute_input_stop(self):
+        """Execute input stop (from UI)"""
+        self.window.dispatch(Event(Event.AUDIO_INPUT_RECORD_TOGGLE, {
+            "state": False,
+            "auto": True,  # do not emit manual event
+        }))
+
+    def is_recording(self) -> bool:
+        """
+        Check if audio input is recording
+
+        :return: True if recording
+        """
+        return self.window.core.plugins.get("audio_input").is_recording()
+
+    def toggle_auto_turn(self):
+        """Toggle auto turn setting"""
+        value = self.window.ui.nodes['audio.auto_turn'].box.isChecked()
+        self.window.core.config.set("audio.input.auto_turn", value)
+        self.window.core.config.save()
+
+    def toggle_loop(self):
+        """Toggle loop recording setting"""
+        value = self.window.ui.nodes['audio.loop'].box.isChecked()
+        self.window.core.config.set("audio.input.loop", value)
+        self.window.core.config.save()
+
     def toggle_input(
             self,
             state: bool,
@@ -410,18 +450,18 @@ class Audio:
             # show/hide extra options
             tab = self.window.controller.ui.tabs.get_current_tab()
             if tab.type == Tab.TAB_NOTEPAD:
-                self.window.ui.plugin_addon['audio.input.btn'].notepad_footer.setVisible(True)
+                self.window.controller.audio.ui.on_input_continuous_enable("input")
             else:
-                self.window.ui.plugin_addon['audio.input.btn'].notepad_footer.setVisible(False)
+                self.window.controller.audio.ui.on_input_continuous_disable("input")
             if is_advanced:
-                self.window.ui.plugin_addon['audio.input.btn'].setVisible(False)
+                self.window.controller.audio.ui.on_input_disable("input")
                 self.window.ui.plugin_addon['audio.input'].setVisible(True)
             else:
-                self.window.ui.plugin_addon['audio.input.btn'].setVisible(True)  # simple recording
+                self.window.controller.audio.ui.on_input_enable("input")
                 self.window.ui.plugin_addon['audio.input'].setVisible(False)  # advanced recording
             self.toggle_input_icon(True)
         else:
-            self.window.ui.plugin_addon['audio.input.btn'].setVisible(False)  # simple recording
+            self.window.controller.audio.ui.on_input_disable("input")  # simple recording
             self.window.ui.plugin_addon['audio.input'].setVisible(False)  # advanced recording
             self.toggle_input_icon(False)
 
