@@ -295,7 +295,7 @@ class Ctx:
 
     def clean_memory(self):
         """Clean memory"""
-        self.window.core.api.openai.close()  # clear gpt client
+        pass
 
     def new_in_group(
             self,
@@ -1284,6 +1284,12 @@ class Ctx:
         """Clear selected list"""
         self.selected.clear()
 
+    def fresh_current_output(self):
+        """Fresh output for current context"""
+        meta = self.window.core.ctx.get_meta_by_id(self.window.core.ctx.get_current())
+        if meta is not None:
+            self.fresh_output(meta)
+
     def fresh_output(self, meta: CtxMeta):
         """
         Fresh output for new context
