@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.18 01:00:00                  #
+# Updated Date: 2025.09.12 20:00:00                  #
 # ================================================== #
 
 from datetime import datetime
@@ -18,6 +18,8 @@ from PySide6.QtGui import QTextCursor
 
 from pygpt_net.core.events import RenderEvent
 
+from .fixtures import Fixtures
+
 
 class Debug(QObject):
     def __init__(self, window=None):
@@ -28,13 +30,17 @@ class Debug(QObject):
         """
         super(Debug, self).__init__()
         self.window = window
+        self.fixtures = Fixtures(window)
         self.is_logger = False  # logger window opened
         self.is_app_log = False  # app log window opened
+        self.is_fake_stream = False  # fake stream enabled
         self.allow_level_change = False  # allow changing log level
+        self._ids = None
 
     def update(self):
         """Update debug"""
         self.update_menu()
+        self.fixtures.update()
 
     def update_menu(self):
         """Update debug menu"""
@@ -100,12 +106,11 @@ class Debug(QObject):
 
         :param all: update all debug windows
         """
-        # not_realtime = ['context']
-        not_realtime = []
-        for id in self.window.controller.dialogs.debug.get_ids():
+        if self._ids is None:
+            self._ids = self.window.controller.dialogs.debug.get_ids()
+        for id in self._ids:
             if self.window.controller.dialogs.debug.is_active(id):
-                if all or id not in not_realtime:
-                    self.window.controller.dialogs.debug.update_worker(id)
+                self.window.controller.dialogs.debug.update_worker(id)
 
     def post_setup(self):
         """Post setup debug"""
@@ -126,6 +131,8 @@ class Debug(QObject):
                 print("[LOGGER] Switching to: " + level)
                 self.set_log_level(level)
 
+        self.fixtures.setup()
+
     def connect_signals(self):
         """Connect signals"""
         # webengine debug signals
