@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 03:00:00                  #
+# Updated Date: 2025.08.24 23:00:00                  #
 # ================================================== #
 
 from typing import Any
@@ -14,7 +14,7 @@ from typing import Any
 from PySide6.QtWidgets import QApplication
 
 from pygpt_net.core.events import Event, KernelEvent
-from pygpt_net.utils import trans
+from pygpt_net.utils import trans, freeze_updates
 
 
 class Settings:
@@ -52,7 +52,8 @@ class Settings:
                 'status': trans("status.loading")
             }))
             QApplication.processEvents()
-            self.setup()
+            with freeze_updates(self.window):
+                self.setup()
             self.config_initialized = True
         if self.config_dialog:
             return
@@ -138,10 +139,9 @@ class Settings:
         window.controller.plugins.presets.save_current()
         window.core.config.save()
         self.close()
-        window.update_status(trans('info.settings.saved'))
 
-        event = Event(Event.PLUGIN_SETTINGS_CHANGED)
-        window.dispatch(event)
+        window.update_status(trans('info.settings.saved'))
+        window.dispatch(Event(Event.PLUGIN_SETTINGS_CHANGED))
         window.controller.ui.update_tokens()
 
     def close(self):
