@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 03:00:00                  #
+# Updated Date: 2025.08.24 23:00:00                  #
 # ================================================== #
 
 from typing import Any, Optional, Tuple
@@ -134,8 +134,7 @@ class Tabs:
     def reload(self):
         """Reload tabs"""
         self.window.core.tabs.reload()
-        event = RenderEvent(RenderEvent.PREPARE)
-        self.window.dispatch(event)
+        self.window.dispatch(RenderEvent(RenderEvent.PREPARE))
         self.debug()
 
     def reload_after(self):
@@ -171,6 +170,7 @@ class Tabs:
         w = self.window
         core = w.core
         tabs_core = core.tabs
+        appended = self.appended
 
         tab = tabs_core.get_tab_by_index(idx, column_idx)
         if tab is None:
@@ -186,6 +186,8 @@ class Tabs:
                     if meta is not None:
                         w.controller.ctx.load(meta.id)
                 self.create_new_on_tab = True
+            else:
+                self.current = idx
 
         prev_tab = self.current
         prev_column = self.column_idx
@@ -198,6 +200,8 @@ class Tabs:
         if tab.type == Tab.TAB_NOTEPAD:
             w.controller.notepad.opened_once = True
             w.controller.notepad.on_open(idx, column_idx)
+            if appended:
+                w.controller.notepad.focus_opened(tab)
         elif tab.type == Tab.TAB_CHAT:
             meta_id = tab.data_id
             if meta_id is None:
