@@ -245,18 +245,36 @@ class Files:
             if store_id is None or store_id == "":
                 continue  # skip if no store_id
             try:
-                self.window.core.gpt.store.delete_store_file(store_id, file_id)  # remove from vector store
+                self.window.core.api.openai.store.delete_store_file(store_id, file_id)  # remove from vector store
             except Exception as e:
                 self.window.core.debug.log("Failed to delete file from vector store: " + str(e))
         self.provider.delete_by_id(file.record_id)  # delete file in DB
         try:
-            self.window.core.gpt.store.delete_file(file.file_id)  # delete file in API
+            self.window.core.api.openai.store.delete_file(file.file_id)  # delete file in API
         except Exception as e:
             self.window.core.debug.log("Failed to delete remote file: " + str(e))
         if file.record_id in self.items:
             del self.items[file.record_id]
         return True
 
+    def delete_by_file_id(self, file_id: str) -> bool:
+        """
+        Delete file by file ID
+
+        :param file_id: file ID
+        :return: True if deleted
+        """
+        res = self.provider.delete_by_file_id(file_id)
+        if res:
+            # remove from items
+            to_delete = []
+            for id in self.items:
+                if self.items[id].file_id == file_id:
+                    to_delete.append(id)
+            for id in to_delete:
+                del self.items[id]
+        return res
+
     def on_store_deleted(self, store_id: str):
         """
         Clear deleted store from files
@@ -290,9 +308,9 @@ class Files:
         :return: True if truncated
         """
         if store_id is not None:
-            self.window.core.gpt.store.remove_from_store(store_id)  # remove files from vector store
+            self.window.core.api.openai.store.remove_from_store(store_id)  # remove files from vector store
         else:
-            self.window.core.gpt.store.remove_from_stores()  # remove files from all vector stores
+            self.window.core.api.openai.store.remove_from_stores()  # remove files from all vector stores
         return self.truncate_local(store_id)  # truncate files in DB
 
     def truncate_local(self, store_id: Optional[str] = None) -> bool:
@@ -316,7 +334,7 @@ class Files:
         :param store_id: store ID
         :return: True if imported
         """
-        files = self.window.core.gpt.store.import_store_files(store_id)
+        files = self.window.core.api.openai.store.import_store_files(store_id)
         for file in files:
             self.create(file.assistant, file.thread_id, file.file_id, file.name, file.path, file.size)
         return True
