@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.23 21:00:00                  #
+# Updated Date: 2025.08.11 14:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Signal, QObject, QRunnable, Slot
@@ -19,7 +19,7 @@ class WorkerSignals(QObject):
 
 class AttachmentWorker(QRunnable):
     def __init__(self, *args, **kwargs):
-        super(AttachmentWorker, self).__init__()
+        super().__init__()
         self.signals = WorkerSignals()
         self.args = args
         self.kwargs = kwargs
@@ -34,7 +34,22 @@ class AttachmentWorker(QRunnable):
         try:
             self.window.controller.chat.attachment.upload(self.meta, self.mode, self.prompt)
             self.signals.success.emit(self.prompt)
+
         except Exception as e:
             if self.signals is not None:
                 self.signals.error.emit(e)
-            print("Attachment indexing error", e)
\ No newline at end of file
+            self.window.core.debug.error(e)
+            print("Attachment indexing error", e)
+
+        finally:
+            self.cleanup()
+
+    def cleanup(self):
+        """Cleanup resources after worker execution."""
+        sig = self.signals
+        self.signals = None
+        if sig is not None:
+            try:
+                sig.deleteLater()
+            except RuntimeError:
+                pass
\ No newline at end of file
