@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 23:00:00                  #
+# Updated Date: 2025.08.28 09:00:00                  #
 # ================================================== #
 
 from typing import Dict, List
@@ -53,7 +53,7 @@ class Modes:
             MODE_IMAGE,
             # MODE_LANGCHAIN,
             MODE_LLAMA_INDEX,
-            MODE_VISION,
+            # MODE_VISION,
             MODE_RESEARCH,
             MODE_COMPUTER,
         )
