@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 08:00:00                  #
+# Updated Date: 2025.08.21 00:00:00                  #
 # ================================================== #
 
 from typing import Optional, List, Dict
@@ -40,12 +40,9 @@ class Body:
         """
         num_str = ""
         if num is not None and num_all is not None and num_all > 1:
-            num_str = " [{}]".format(num)
+            num_str = f" [{num}]"
         url, path = self.window.core.filesystem.extract_local_url(url)
-        return """\n{prefix}{num}: {path}\n""". \
-            format(prefix=trans('chat.prefix.img'),
-                   path=path,
-                   num=num_str)
+        return f"\n{trans('chat.prefix.img')}{num_str}: {path}\n"
 
     def get_url_html(
             self,
@@ -63,11 +60,8 @@ class Body:
         """
         num_str = ""
         if num is not None and num_all is not None and num_all > 1:
-            num_str = " [{}]".format(num)
-        return """{prefix}{num}: {url}""". \
-            format(prefix=trans('chat.prefix.url'),
-                   url=url,
-                   num=num_str)
+            num_str = f" [{num}]"
+        return f"{trans('chat.prefix.url')}{num_str}: {url}"
 
     def get_docs_html(self, docs: List[Dict]) -> str:
         """
@@ -93,8 +87,8 @@ class Body:
                     """
                     doc_parts = []
                     for key in doc_json:
-                        doc_parts.append("{}: {}".format(key, doc_json[key]))
-                    html_sources += "\n[{}] {}: {}".format(num, uuid, ", ".join(doc_parts))
+                        doc_parts.append(f"{key}: {doc_json[key]}")
+                    html_sources += f"\n[{num}] {uuid}: {', '.join(doc_parts)}"
                     num += 1
                 if num >= max:
                     break
@@ -102,7 +96,7 @@ class Body:
             pass
 
         if html_sources != "":
-            html += "\n----------\n{prefix}:\n".format(prefix=trans('chat.prefix.doc'))
+            html += f"\n----------\n{trans('chat.prefix.doc')}:\n"
             html += html_sources
         return html
 
@@ -122,9 +116,6 @@ class Body:
         """
         num_str = ""
         if num is not None and num_all is not None and num_all > 1:
-            num_str = " [{}]".format(num)
+            num_str = f" [{num}]"
         url, path = self.window.core.filesystem.extract_local_url(url)
-        return """\n{prefix}{num}: {path}\n""". \
-            format(prefix=trans('chat.prefix.file'),
-                   path=path,
-                   num=num_str)
+        return f"\n{trans('chat.prefix.file')}{num_str}: {path}\n"
\ No newline at end of file
