@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.12 19:00:00                  #
+# Updated Date: 2025.08.26 01:00:00                  #
 # ================================================== #
 
 from dataclasses import dataclass
@@ -16,7 +16,6 @@ from agents import (
     Agent as OpenAIAgent,
     Runner,
     RunConfig,
-    ModelSettings,
     TResponseInputItem,
 )
 
@@ -31,13 +30,13 @@ from pygpt_net.item.ctx import CtxItem
 from pygpt_net.item.model import ModelItem
 from pygpt_net.item.preset import PresetItem
 
-from pygpt_net.provider.gpt.agents.client import get_custom_model_provider, set_openai_env
-from pygpt_net.provider.gpt.agents.remote_tools import get_remote_tools, is_computer_tool, append_tools
-from pygpt_net.provider.gpt.agents.response import StreamHandler
+from pygpt_net.provider.api.openai.agents.client import get_custom_model_provider, set_openai_env
+from pygpt_net.provider.api.openai.agents.remote_tools import append_tools
+from pygpt_net.provider.api.openai.agents.response import StreamHandler
+from pygpt_net.provider.api.openai.agents.experts import get_experts
+from pygpt_net.utils import trans
 
 from ..base import BaseAgent
-from ...gpt.agents.experts import get_experts
-
 
 @dataclass
 class EvaluationFeedback:
@@ -115,7 +114,7 @@ class Agent(BaseAgent):
         kwargs = {
             "name": agent_name,
             "instructions": self.get_option(preset, "base", "prompt"),
-            "model": model.id,
+            "model": window.core.agents.provider.get_openai_model(model),
         }
         if handoffs:
             kwargs["handoffs"] = handoffs
@@ -156,7 +155,7 @@ class Agent(BaseAgent):
         kwargs = {
             "name": "evaluator",
             "instructions": instructions,
-            "model": model.id,
+            "model": window.core.agents.provider.get_openai_model(model),
             "output_type": EvaluationFeedback,
         }
         tool_kwargs = append_tools(
@@ -195,7 +194,7 @@ class Agent(BaseAgent):
         kwargs = {
             "name": "StructuredPlanner",
             "instructions": instructions,
-            "model": model.id,
+            "model": window.core.agents.provider.get_openai_model(model),
             "output_type": StructuredPlan,
         }
         tool_kwargs = append_tools(
@@ -327,7 +326,7 @@ class Agent(BaseAgent):
                     print("Final response:", result)
 
                 input_items = result.to_input_list()
-                final_output, last_response_id = window.core.gpt.responses.unpack_agent_response(result, ctx)
+                final_output, last_response_id = window.core.api.openai.responses.unpack_agent_response(result, ctx)
 
                 if bridge.stopped():
                     bridge.on_stop(ctx)
@@ -390,9 +389,9 @@ class Agent(BaseAgent):
                 evaluator_result = await Runner.run(evaluator, input_items)
                 result: EvaluationFeedback = evaluator_result.final_output
 
-                info = f"\n___\n**Evaluator score: {result.score}**\n\n"
+                info = f"\n___\n**{trans('agent.eval.score')}: {result.score}**\n\n"
                 if result.score == "pass":
-                    info += "\n\n**Response is good enough, exiting.**\n"
+                    info += f"\n\n**{trans('agent.eval.score.good')}**\n"
                     if use_partial_ctx:
                         ctx = bridge.on_next_ctx(
                             ctx=ctx,
@@ -408,7 +407,7 @@ class Agent(BaseAgent):
                         final_output += info
                     break
 
-                info += "\n\n**Re-running with feedback**\n\n" + f"Feedback: {result.feedback}\n___\n"
+                info += f"\n\n**{trans('agent.eval.next')}**\n\nFeedback: {result.feedback}\n___\n"
                 input_items.append({"content": f"Feedback: {result.feedback}", "role": "user"})
 
                 if use_partial_ctx:
@@ -436,82 +435,82 @@ class Agent(BaseAgent):
         """
         return {
             "base": {
-                "label": "Base agent",
+                "label": trans("agent.option.section.base"),
                 "options": {
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for base agent",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.base.desc"),
                         "default": self.PROMPT,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for this agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for this agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": False,
                     },
                 }
             },
             "planner": {
-                "label": "Planner",
+                "label": trans("agent.option.section.planner"),
                 "options": {
                     "model": {
-                        "label": "Model",
+                        "label": trans("agent.option.model"),
                         "type": "combo",
                         "use": "models",
                         "default": "o3-mini-low",
                     },
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for planner agent",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.planner.desc"),
                         "default": self.PROMPT_PLANNER,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for planner agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for planner agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": False,
                     },
                 }
             },
             "feedback": {
-                "label": "Feedback",
+                "label": trans("agent.option.section.feedback"),
                 "options": {
                     "model": {
-                        "label": "Model",
+                        "label": trans("agent.option.model"),
                         "type": "combo",
                         "use": "models",
                         "default": "gpt-4o",
                     },
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for feedback evaluation",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.feedback.desc"),
                         "default": self.PROMPT_FEEDBACK,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for this agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for this agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": False,
                     },
                 }
