@@ -6,16 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.12 19:00:00                  #
+# Updated Date: 2025.08.26 01:00:00                  #
 # ================================================== #
 
 from typing import Dict, Any, Tuple, Union, Optional
 
 from agents import (
     Agent as OpenAIAgent,
-    Runner,
-    RunConfig,
-    ModelSettings,
 )
 
 from pygpt_net.core.agents.bridge import ConnectionContext
@@ -27,15 +24,13 @@ from pygpt_net.core.types import (
 
 from pygpt_net.item.ctx import CtxItem
 from pygpt_net.item.model import ModelItem
-from pygpt_net.item.preset import PresetItem
 
-from pygpt_net.provider.gpt.agents.client import get_custom_model_provider, set_openai_env
-from pygpt_net.provider.gpt.agents.remote_tools import append_tools
-from pygpt_net.provider.gpt.agents.response import StreamHandler
+from pygpt_net.provider.api.openai.agents.remote_tools import append_tools
+from pygpt_net.provider.api.openai.agents.experts import get_experts
+from pygpt_net.utils import trans
 
 from ..base import BaseAgent
 from .bots.research_bot.manager import ResearchManager
-from ...gpt.agents.experts import get_experts
 
 
 class Agent(BaseAgent):
@@ -89,7 +84,7 @@ class Agent(BaseAgent):
         kwargs = {
             "name": agent_name,
             "instructions": system_prompt,
-            "model": model.id,
+            "model": window.core.agents.provider.get_openai_model(model),
             "handoffs": handoffs,
         }
         tool_kwargs = append_tools(
@@ -154,18 +149,6 @@ class Agent(BaseAgent):
         model_search_kwargs = {}
         model_planner_kwargs = {}
 
-        if model.provider != "openai":
-            custom_provider = get_custom_model_provider(window, model)
-            model_kwargs["run_config"] = RunConfig(model_provider=custom_provider)
-
-        if model_search.provider != "openai":
-            custom_provider = get_custom_model_provider(window, model_search)
-            model_search_kwargs["run_config"] = RunConfig(model_provider=custom_provider)
-
-        if model_planner.provider != "openai":
-            custom_provider = get_custom_model_provider(window, model_planner)
-            model_planner_kwargs["run_config"] = RunConfig(model_provider=custom_provider)
-
         # get experts
         experts = get_experts(
             window=window,
@@ -207,10 +190,6 @@ class Agent(BaseAgent):
             },
             history=messages if messages else [],
         )
-
-        if model.provider == "openai":
-            set_openai_env(window)
-
         final_output = await bot.run(query)
         return ctx, final_output, response_id
 
@@ -223,82 +202,82 @@ class Agent(BaseAgent):
         """
         return {
             "writer": {
-                "label": "Base agent",
+                "label": trans("agent.option.section.base"),
                 "options": {
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for base agent",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.base.desc"),
                         "default": self.PROMPT_WRITER,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for this agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for this agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": False,
                     },
                 }
             },
             "planner": {
-                "label": "Planner",
+                "label": trans("agent.option.section.planner"),
                 "options": {
                     "model": {
-                        "label": "Model",
+                        "label": trans("agent.option.model"),
                         "type": "combo",
                         "use": "models",
                         "default": "gpt-4o",
                     },
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for planner agent",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.planner.desc"),
                         "default": self.PROMPT_PLANNER,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for this agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for this agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": False,
                     },
                 }
             },
             "search": {
-                "label": "Search",
+                "label": trans("agent.option.section.search"),
                 "options": {
                     "model": {
-                        "label": "Model",
+                        "label": trans("agent.option.model"),
                         "type": "combo",
                         "use": "models",
                         "default": "gpt-4o",
                     },
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for search agent",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.search.desc"),
                         "default": self.PROMPT_SEARCH,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for this agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for this agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": True,
                     },
                 }
