@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.02 20:00:00                  #
+# Updated Date: 2025.08.28 09:00:00                  #
 # ================================================== #
 
 import os
@@ -18,7 +18,8 @@ from llama_index.core.multi_modal_llms import MultiModalLLM as LlamaMultiModalLL
 
 from pygpt_net.core.types import (
     MODE_LANGCHAIN,
-    MODE_LLAMA_INDEX, MODE_CHAT,
+    MODE_LLAMA_INDEX, 
+    MODE_CHAT,
 )
 from pygpt_net.item.model import ModelItem
 from pygpt_net.utils import parse_args
@@ -221,7 +222,7 @@ class BaseLLM:
         """
         model = ModelItem()
         model.provider = self.id
-        return window.core.gpt.get_client(
+        return window.core.api.openai.get_client(
             mode=MODE_CHAT,
             model=model,
         )
