@@ -6,9 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.06 01:00:00                  #
+# Updated Date: 2025.08.26 19:00:00                  #
 # ================================================== #
-from typing import List, Dict
+
+from typing import List, Dict, Optional
+
+from llama_index.core.base.embeddings.base import BaseEmbedding
 
 from pygpt_net.core.types import (
     MODE_LLAMA_INDEX,
@@ -24,7 +27,7 @@ class DeepseekApiLLM(BaseLLM):
         super(DeepseekApiLLM, self).__init__(*args, **kwargs)
         self.id = "deepseek_api"
         self.name = "Deepseek API"
-        self.type = [MODE_LLAMA_INDEX]
+        self.type = [MODE_LLAMA_INDEX, "embeddings"]
 
     def llama(
             self,
@@ -42,8 +45,38 @@ class DeepseekApiLLM(BaseLLM):
         """
         from llama_index.llms.deepseek import DeepSeek
         args = self.parse_args(model.llama_index, window)
+        if "model" not in args:
+            args["model"] = model.id
+        if "api_key" not in args or args["api_key"] == "":
+            args["api_key"] = window.core.config.get("api_key_deepseek", "")
         return DeepSeek(**args)
 
+    def get_embeddings_model(
+            self,
+            window,
+            config: Optional[List[Dict]] = None
+    ) -> BaseEmbedding:
+        """
+        Return provider instance for embeddings
+
+        :param window: window instance
+        :param config: config keyword arguments list
+        :return: Embedding provider instance
+        """
+        from llama_index.embeddings.voyageai import VoyageEmbedding
+        args = {}
+        if config is not None:
+            args = self.parse_args({
+                "args": config,
+            }, window)
+        if "api_key" in args:
+            args["voyage_api_key"] = args.pop("api_key")
+        if "voyage_api_key" not in args or args["voyage_api_key"] == "":
+            args["voyage_api_key"] = window.core.config.get("api_key_voyage", "")
+        if "model" in args and "model_name" not in args:
+            args["model_name"] = args.pop("model")
+        return VoyageEmbedding(**args)
+
     def get_models(
             self,
             window,
