@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.06 01:00:00                  #
+# Updated Date: 2025.08.30 06:00:00                  #
 # ================================================== #
 
 from typing import Optional, List, Dict
@@ -53,6 +53,10 @@ class GoogleLLM(BaseLLM):
         args = self.parse_args(model.llama_index, window)
         if "model" not in args:
             args["model"] = model.id
+        if "api_key" not in args or args["api_key"] == "":
+            args["api_key"] = window.core.config.get("api_key_google", "")
+
+        window.core.api.google.setup_env()  # setup VertexAI if configured
         return GoogleGenAI(**args)
 
     def get_embeddings_model(
@@ -67,13 +71,19 @@ class GoogleLLM(BaseLLM):
         :param config: config keyword arguments list
         :return: Embedding provider instance
         """
-        from llama_index.embeddings.gemini import GeminiEmbedding
+        from llama_index.embeddings.google_genai import GoogleGenAIEmbedding
         args = {}
         if config is not None:
             args = self.parse_args({
                 "args": config,
             }, window)
-        return GeminiEmbedding(**args)
+        if "api_key" not in args or args["api_key"] == "":
+            args["api_key"] = window.core.config.get("api_key_google", "")
+        if "model" in args and "model_name" not in args:
+            args["model_name"] = args.pop("model")
+
+        window.core.api.google.setup_env()  # setup VertexAI if configured
+        return GoogleGenAIEmbedding(**args)
 
     def get_models(
             self,
@@ -86,13 +96,12 @@ class GoogleLLM(BaseLLM):
         :return: list of models
         """
         items = []
-        client = self.get_client(window)
+        client = window.core.api.google.get_client()
         models_list = client.models.list()
-        if models_list.data:
-            for item in models_list.data:
-                id = item.id.replace("models/", "")
-                items.append({
-                    "id": id,
-                    "name": id,
-                })
+        for item in models_list:
+            id = item.name.replace("models/", "")
+            items.append({
+                "id": id,
+                "name": id,  # TODO: token limit get from API
+            })
         return items
