@@ -6,20 +6,20 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.24 23:00:00                  #
+# Updated Date: 2025.09.05 18:00:00                  #
 # ================================================== #
 
 import copy
+from typing import Dict, List, Optional
 
 from PySide6.QtCore import Qt
 from PySide6.QtGui import QStandardItemModel, QIcon
 from PySide6.QtWidgets import QPushButton, QHBoxLayout, QLabel, QVBoxLayout, QScrollArea, QWidget, QTabWidget, QFrame, \
     QSplitter, QSizePolicy
 
-from pygpt_net.item.model import ModelItem
 from pygpt_net.ui.widget.dialog.model import ModelDialog
 from pygpt_net.ui.widget.element.group import CollapsedGroup
-from pygpt_net.ui.widget.element.labels import UrlLabel
+from pygpt_net.ui.widget.element.labels import UrlLabel, DescLabel
 from pygpt_net.ui.widget.lists.model_editor import ModelEditorList
 from pygpt_net.ui.widget.option.checkbox import OptionCheckbox
 from pygpt_net.ui.widget.option.checkbox_list import OptionCheckboxList
@@ -28,8 +28,10 @@ from pygpt_net.ui.widget.option.dictionary import OptionDict
 from pygpt_net.ui.widget.option.input import OptionInput, PasswordInput
 from pygpt_net.ui.widget.option.slider import OptionSlider
 from pygpt_net.ui.widget.option.textarea import OptionTextarea
+from pygpt_net.ui.widget.textarea.search_input import SearchInput
 from pygpt_net.utils import trans
 
+
 class Models:
     def __init__(self, window=None):
         """
@@ -40,6 +42,13 @@ class Models:
         self.window = window
         self.dialog_id = "models.editor"
 
+        # Internal state for filtering/mapping
+        self._filter_text: str = ""
+        self._filtered_ids: List[str] = []     # current list of model keys displayed in the view (order matters)
+        self._index_to_id: List[str] = []      # row index -> model key
+        self._id_to_index: Dict[str, int] = {} # model key -> row index
+        self._all_data: Dict[str, object] = {} # last known (unfiltered) data snapshot used to render the list
+
     def setup(self, idx=None):
         """
         Setup editor dialog
@@ -56,13 +65,17 @@ class Models:
             QPushButton(trans("dialog.models.editor.btn.save"))
 
         self.window.ui.nodes['models.editor.btn.new'].clicked.connect(
-            lambda: self.window.controller.model.editor.new())
+            lambda: self.window.controller.model.editor.new()
+        )
         self.window.ui.nodes['models.editor.btn.defaults.user'].clicked.connect(
-            lambda: self.window.controller.model.editor.load_defaults_user())
+            lambda: self.window.controller.model.editor.load_defaults_user()
+        )
         self.window.ui.nodes['models.editor.btn.defaults.app'].clicked.connect(
-            lambda: self.window.controller.model.editor.load_defaults_app())
+            lambda: self.window.controller.model.editor.load_defaults_app()
+        )
         self.window.ui.nodes['models.editor.btn.save'].clicked.connect(
-            lambda: self.window.controller.model.editor.save())
+            lambda: self.window.controller.model.editor.save()
+        )
 
         # set enter key to save button
         self.window.ui.nodes['models.editor.btn.new'].setAutoDefault(False)
@@ -111,17 +124,16 @@ class Models:
         # append advanced options at the end
         if len(advanced_keys) > 0:
             group_id = 'models.editor.advanced'
-            self.window.ui.groups[group_id] = CollapsedGroup(self.window, group_id, None, False, None)
-            self.window.ui.groups[group_id].box.setText(trans('settings.advanced.collapse'))
+            group = CollapsedGroup(self.window, group_id, None, False, None)
+            group.box.setText(trans('settings.advanced.collapse'))
             for key in widgets:
                 if key not in advanced_keys:  # ignore non-advanced options
                     continue
-
-                option = self.add_option(widgets[key], options[key])  # build option
-                self.window.ui.groups[group_id].add_layout(option)  # add option to group
+                group.add_layout(self.add_option(widgets[key], options[key]))  # add option to group
 
             # add advanced options group to scroll
-            content.addWidget(self.window.ui.groups[group_id])
+            content.addWidget(group)
+            self.window.ui.groups[group_id] = group
 
         content.addStretch()
 
@@ -146,16 +158,29 @@ class Models:
         self.window.ui.nodes[id] = ModelEditorList(self.window, id)
         self.window.ui.models[id] = self.create_model(self.window)
         self.window.ui.nodes[id].setModel(self.window.ui.models[id])
+        self.window.ui.nodes[id].setMinimumWidth(250)  # set max width to list
 
-        # update models list
+        # search input (placed above the list)
+        self.window.ui.nodes['models.editor.search'] = SearchInput()
+        # Connect to provided callback API (callables assigned to attributes)
+        self.window.ui.nodes['models.editor.search'].on_search = self._on_search_models
+        self.window.ui.nodes['models.editor.search'].on_clear = self._on_clear_models  # clear via "X" button
+
+        # container for search + list (left panel)
+        left_layout = QVBoxLayout()
+        left_layout.setContentsMargins(0, 0, 0, 0)
+        left_layout.setSpacing(6)
+        left_layout.addWidget(self.window.ui.nodes['models.editor.search'])
+        left_layout.addWidget(self.window.ui.nodes[id])
+        left_widget = QWidget()
+        left_widget.setLayout(left_layout)
+
+        # update models list (initial, unfiltered)
         self.update_list(id, data)
 
-        # set max width to list
-        self.window.ui.nodes[id].setMinimumWidth(250)
-
         # splitter
         self.window.ui.splitters['dialog.models'] = QSplitter(Qt.Horizontal)
-        self.window.ui.splitters['dialog.models'].addWidget(self.window.ui.nodes[id])  # list
+        self.window.ui.splitters['dialog.models'].addWidget(left_widget)  # search + list
         self.window.ui.splitters['dialog.models'].addWidget(area_widget)  # tabs
         self.window.ui.splitters['dialog.models'].setStretchFactor(0, 2)
         self.window.ui.splitters['dialog.models'].setStretchFactor(1, 5)
@@ -182,6 +207,86 @@ class Models:
             if self.window.controller.model.editor.current is None:
                 self.window.controller.model.editor.set_by_tab(0)
 
+    def _on_search_models(self, text: str):
+        """
+        Handle SearchInput callback. Filtering is prefix-based on model id or name (case-insensitive).
+        """
+        # Keep normalized filter text
+        self._filter_text = (text or "").strip().casefold()
+        # Re-apply list render using the last known dataset
+        self.update_list('models.list', self._all_data)
+        # Do not force-select rows here to avoid heavy editor re-initialization on each keystroke.
+
+    def _on_clear_models(self):
+        """
+        Handle SearchInput clear (click on 'X' button).
+        """
+        if not self._filter_text:
+            return
+        self._filter_text = ""
+        self.update_list('models.list', self._all_data)
+        # Try to restore selection for the current model if it is visible again.
+        self._restore_selection_for_current()
+
+    def _restore_selection_for_current(self):
+        """
+        Attempt to restore selection on the list to the current editor model if present in the view.
+        """
+        current_id = getattr(self.window.controller.model.editor, "current", None)
+        if not current_id:
+            return
+        idx = self.get_row_by_model_id(current_id)
+        if idx is None:
+            return
+        current = self.window.ui.models['models.list'].index(idx, 0)
+        self.window.ui.nodes['models.list'].setCurrentIndex(current)
+
+    def _apply_filter(self, data: Dict[str, object]) -> Dict[str, object]:
+        """
+        Return filtered data view, preserving original order.
+        """
+        if not self._filter_text:
+            return data
+
+        out: Dict[str, object] = {}
+        needle = self._filter_text
+        for mid, item in data.items():
+            # Normalize fields for prefix matching
+            model_id = (str(getattr(item, "id", mid)) or "").casefold()
+            model_name = (getattr(item, "name", "") or "").casefold()
+            if (needle in model_name
+                    or needle in model_id):
+                out[mid] = item
+        return out
+
+    def _refresh_index_mapping(self, ids: List[str]):
+        """
+        Build fast row<->id mapping for the current filtered list.
+        """
+        self._filtered_ids = list(ids)
+        self._index_to_id = list(ids)
+        self._id_to_index = {mid: idx for idx, mid in enumerate(ids)}
+
+    def get_model_id_by_row(self, row: int) -> Optional[str]:
+        """
+        Map a view row index to the model id currently displayed at that row.
+        """
+        if 0 <= row < len(self._index_to_id):
+            return self._index_to_id[row]
+        return None
+
+    def get_row_by_model_id(self, model_id: str) -> Optional[int]:
+        """
+        Map a model id to its current row index in the filtered view.
+        """
+        return self._id_to_index.get(model_id)
+
+    def get_filtered_ids(self) -> List[str]:
+        """
+        Return a copy of currently visible model ids (filtered order).
+        """
+        return list(self._filtered_ids)
+
     def build_widgets(self, options: dict) -> dict:
         """
         Build settings options widgets
@@ -303,10 +408,8 @@ class Models:
             layout.addWidget(widget)
 
         if desc:
-            self.window.ui.nodes[desc_key] = QLabel(desc)
-            self.window.ui.nodes[desc_key].setWordWrap(True)
+            self.window.ui.nodes[desc_key] = DescLabel(desc)
             self.window.ui.nodes[desc_key].setMaximumHeight(40)
-            self.window.ui.nodes[desc_key].setStyleSheet("font-size: 10px;")
             layout.addWidget(self.window.ui.nodes[desc_key])
 
         line = self.add_line()  # TODO: change name to separator
@@ -333,6 +436,21 @@ class Models:
         """
         return QStandardItemModel(0, 1, parent)
 
+    def _get_provider_display_name(self, provider_id: str) -> str:
+        """
+        Resolve provider display name using app's LLM provider registry.
+        """
+        if not provider_id:
+            return ""
+        try:
+            name = self.window.core.llm.get_provider_name(provider_id)
+            if isinstance(name, str):
+                name = name.strip()
+            return name or ""
+        except Exception:
+            # Fail silently to avoid breaking the models list rendering
+            return ""
+
     def update_list(self, id: str, data: dict):
         """
         Update list
@@ -340,10 +458,40 @@ class Models:
         :param id: ID of the list
         :param data: Data to update
         """
+        # Keep latest source data for subsequent filtering cycles
+        self._all_data = dict(data)
+
+        # Apply current filter (preserve insertion/sorted order)
+        filtered = self._apply_filter(self._all_data)
+
+        # Reset model rows
         self.window.ui.models[id].removeRows(0, self.window.ui.models[id].rowCount())
+
+        # Count occurrences of each model display name to detect duplicates (in filtered view)
+        name_counts = {}
+        for key in filtered:
+            item = filtered[key]
+            base_name = getattr(item, "name", "") or ""
+            name_counts[base_name] = name_counts.get(base_name, 0) + 1
+
+        # Populate rows with optional provider suffix for duplicate names
         i = 0
-        for n in data:
+        row_ids: List[str] = []
+        for n in filtered:
+            item = filtered[n]
+            base_name = getattr(item, "name", "") or ""
+            display_name = base_name
+            if name_counts.get(base_name, 0) > 1:
+                provider_id = getattr(item, "provider", None)
+                provider_name = self._get_provider_display_name(provider_id) if provider_id else ""
+                if provider_name:
+                    display_name = f"{base_name} ({provider_name})"
+
             self.window.ui.models[id].insertRow(i)
-            name = data[n].name
-            self.window.ui.models[id].setData(self.window.ui.models[id].index(i, 0), name)
+            self.window.ui.models[id].setData(self.window.ui.models[id].index(i, 0), display_name)
+            # IMPORTANT: map list row to the dictionary key (stable and unique within models.items)
+            row_ids.append(n)
             i += 1
+
+        # Refresh index mappings used by Editor
+        self._refresh_index_mapping(row_ids)
\ No newline at end of file
