@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.24 23:00:00                  #
+# Updated Date: 2025.09.12 23:00:00                  #
 # ================================================== #
 
 from PySide6 import QtCore
@@ -210,7 +210,7 @@ class CtxList:
                 files_str = ", ".join(files)
                 if len(files_str) > 40:
                     files_str = files_str[:40] + '...'
-                tooltip_str = trans("attachments.ctx.tooltip.list").format(num=len(files)) + ": " + files_str
+                tooltip_str = f"{trans('attachments.ctx.tooltip.list').format(num=len(files))}: {files_str}"
                 group_item.setToolTip(tooltip_str)
 
             group_item.setData(custom_data, QtCore.Qt.ItemDataRole.UserRole)
@@ -264,7 +264,7 @@ class CtxList:
         is_important = data.important
         is_attachment = data.has_additional_ctx()
         in_group = bool(data.group)
-        append_dt = False if (is_group and self._pinned_separators) or ((not is_group) and self._group_separators) else append_dt
+        append_dt = False if (is_group and self._group_separators) or ((not is_group) and self._group_separators) else append_dt
 
         dt = self.convert_date(data.updated)
         date_time_str = datetime.fromtimestamp(data.updated).strftime("%Y-%m-%d %H:%M")
@@ -282,8 +282,7 @@ class CtxList:
             files_str = ", ".join(files)
             if len(files_str) > 40:
                 files_str = files_str[:40] + '...'
-            tooltip_str = trans("attachments.ctx.tooltip.list").format(num=len(files)) + ": " + files_str
-            tooltip_text += "\n" + tooltip_str
+            tooltip_text += f"\n{trans('attachments.ctx.tooltip.list').format(num=len(files))}: {files_str}"
 
         item = Item(name, id)
         item.id = id
@@ -338,4 +337,4 @@ class CtxList:
         elif 30 <= days_ago < 32:
             return trans('dt.month')
         else:
-            return date.strftime("%Y-%m-%d")
+            return date.strftime("%Y-%m-%d")
\ No newline at end of file
