@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.17 03:00:00                  #
+# Updated Date: 2025.08.24 23:00:00                  #
 # ================================================== #
 
 from PySide6.QtWidgets import QVBoxLayout, QWidget
@@ -17,6 +17,7 @@ from pygpt_net.utils import trans
 
 
 class Model:
+
     def __init__(self, window=None):
         """
         Toolbox UI
@@ -25,6 +26,7 @@ class Model:
         """
         self.window = window
         self.id = 'prompt.model'
+        self.label_key = f'{self.id}.label'
 
     def setup(self) -> QWidget:
         """
@@ -42,19 +44,19 @@ class Model:
 
         :return: QVBoxLayout
         """
-        label_key = self.id + '.label'
+        nodes = self.window.ui.nodes
 
-        self.window.ui.nodes[label_key] = TitleLabel(trans("toolbox.model.label"))
-        self.window.ui.nodes[self.id] = ModelCombo(self.window, self.id)
+        label = TitleLabel(trans("toolbox.model.label"))
+        label.setContentsMargins(5, 0, 0, 0)
+        nodes[self.label_key] = label
 
-        header_layout = QVBoxLayout()
-        header_layout.addWidget(self.window.ui.nodes[label_key])
-        header_layout.setContentsMargins(5, 0, 0, 0)
+        combo = ModelCombo(self.window, self.id)
+        nodes[self.id] = combo
 
         layout = QVBoxLayout()
-        layout.addLayout(header_layout)
-        layout.addWidget(self.window.ui.nodes[self.id])
+        layout.addWidget(label)
+        layout.addWidget(combo)
         layout.addStretch()
         layout.setContentsMargins(2, 5, 5, 5)
 
-        return layout
+        return layout
\ No newline at end of file
